.. sidebar:: Key Contributors

    * `Philipp Weiler`_: lead developer since 2021, maintainer
    * `Volker Bergen`_: lead developer 2018-2021, initial conception

.. _Philipp Weiler: https://twitter.com/PhilippWeiler7
.. _Volker Bergen: https://twitter.com/volkerbergen
